/*
 * File:        helloclient.c
 * Copyright:   (c) 2001 The Regents of the University of California
 * Revision:    @(#) $Revision: 4434 $
 * Date:        $Date: 2005-03-17 09:05:29 -0800 (Thu, 17 Mar 2005) $
 * Description: Simple Hello World C client
 *
 */

#include "Hello_World.h"
#include "sidl_header.h"
#include <stdio.h>
#include <stdlib.h>

int main (int argc, char** argv) 
{
  Hello_World h = Hello_World__create();
  char* msg = Hello_World_getMsg(h);
  Hello_World_deleteRef(h);

  printf ("%s\n", msg);
  free(msg);

  return 0;
}
